@@ -10,7 +10,7 @@ import re
 
 load_dotenv(dotenv_path='.env')
 
-class gossip():
+def gossip():
     pusher = None
     channel = None
     chatroom = None
@@ -205,5 +205,5 @@ class gossip():
         except KeyboardInterrupt:
             self.logged()
             
-if __name__ == "__main__":
-    gossip().main()
+#if __name__ == "__main__":
+    #self.main()
